# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['csvcomparer']

package_data = \
{'': ['*']}

install_requires = \
['pandas>=1.4.2,<2.0.0']

entry_points = \
{'console_scripts': ['csvcomparer = csvcomparer.__main__:main']}

setup_kwargs = {
    'name': 'csvcomparer',
    'version': '0.1.0',
    'description': 'Compare delimited files that share a common key.',
    'long_description': '<div id="top"></div>\n\n<!-- BADGES -->\n![Build](https://github.com/bergsmith/csvcomparer/actions/workflows/CI.yaml/badge.svg)\n[![Documentation Status](https://readthedocs.org/projects/csvcomparer/badge/?version=latest)](https://csvcomparer.readthedocs.io/en/latest/?badge=latest)\n[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)\n[![GitHub license](https://badgen.net/github/license/Naereen/Strapdown.js)](https://github.com/Naereen/StrapDown.js/blob/master/LICENSE)\n\n<!-- LOGO -->\n<br />\n<div align="center">\n  <a href="https://github.com/bergsmith/csvcomparer">\n    <img src="https://raw.githubusercontent.com/bergsmith/csvcomparer/main/images/logo.svg" alt="Logo" width="100" height="100">\n  </a>\n  <h3 align="center">csvcomparer</h3>\n  <p align="center">\n    Compare delimited files that share a common key.\n    <br />\n    <a href="http://csvcomparer.rtfd.io/"><strong>Explore the docs »</strong></a>\n    ·\n    <a href="https://github.com/bergsmith/csvcomparer/issues">Report Bug</a>\n    ·\n    <a href="https://github.com/bergsmith/csvcomparer/issues">Request Feature</a>\n  </p>\n</div>\n\n<!-- TABLE OF CONTENTS -->\n<details>\n  <summary>Table of Contents</summary>\n  <ol>\n    <li><a href="#overview">Overview</a></li>\n    <li><a href="#example">Example</a></li>\n    <li><a href="#installation">Installation</a></li>\n    <li><a href="#roadmap">Roadmap</a></li>\n    <li><a href="#contributing">Contributing</a></li>\n    <li><a href="#license">License</a></li>\n    <li><a href="#contact">Contact</a></li>\n    <li><a href="#acknowledgments">Acknowledgments</a></li>\n  </ol>\n</details>\n<br />\n\n<!-- OVERVIEW -->\n## Overview\n**csvcomparer** is an open-source Python project used for determining differences between two delimited files (referred to here as "left" and "right" files) that share a common key, or index. Specifically, **csvcomparer** determines:\n\n  - Columns exclusive to the left and right files, respectively.\n  - Rows exclusive to the left and right files, respectively.\n  - Field-level differences for rows/columns in common between files.\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n## Basic Usage\nAs a python module:\n```python\nfrom csvcomparer import CsvCompare\n\ndiffs = CsvCompare(\n  "<path/to/left_file.csv>",\n  "<path/to/right_file.csv>",\n  "<key>").diffs\n```\n\nAs a command line utility:\n```\n> python csvcomparer left_csv_filepath right_csv_filepath key\n```\n## Examples\n\nProvided the following file data:  \n**_menu_l.csv_**\n|id |name  |pic|price|score|togo|\n|---|------|---|-----|-----|----|\n|1A |beer  |🍺 |$6.00|3.9  |N   |\n|1B |wine  |🍷 |$7.25|4.5  |N   |\n|2A |cheese|🧀 |$4.10|4.0  |Y   |\n|3A |bacon |🥓 |$3.33|4.9  |Y   |\n\n**_menu_r.csv_**\n|id |name  |pic|price|stars|\n|---|------|---|-----|-----|\n|1A |beer  |🍻 |$5.25|3.9  |\n|1B |wine  |🍷 |$7.25|4.8  |\n|2A |cheese|🧀 |$3.95|4.1  |\n|4C |taco  |🌮 |$8.33|3.1  |\n|5B |pizza |🍕 |$9.99|2.4  |\n\n\nUsage as a Python module...\n```python\n>>> from csvcomparer import CsvCompare\n>>> CsvCompare("menu_l.csv", "menu_r.csv", "id").diffs\n```\n... or as a command-line utility:\n```sh\n> python csvcomparer menu_l.csv menu_r.csv id\n```\nReturns:\n```sh\n{\'cols_added\': [\'stars\'],\n \'cols_removed\': [\'score\', \'togo\'],\n \'rows_added\': {\'4C\': {\'name\': \'taco\',\n                       \'pic\': \'🌮\',\n                       \'price\': \'$8.33\',\n                       \'stars\': 3.1},\n                \'5B\': {\'name\': \'pizza\',\n                       \'pic\': \'🍕\',\n                       \'price\': \'$9.99\',\n                       \'stars\': 2.4}},\n \'rows_changed\': {\'1A\': [(\'pic\', \'🍺\', \'🍻\'), (\'price\', \'$6.00\', \'$5.25\')],\n                  \'2A\': [(\'price\', \'$4.10\', \'$3.95\')]},\n \'rows_removed\': {\'3A\': {\'name\': \'bacon\',\n                         \'pic\': \'🥓\',\n                         \'price\': \'$3.33\',\n                         \'score\': 4.9,\n                         \'togo\': \'Y\'}}}\n\n```                     \nMulti-column keys are also supported. So for the same file data:\n```python\n>>> CsvCompare("menu_l.csv", "menu_r.csv", ["id", "name"]).diffs\n```\nReturns:\n```sh\n{\'cols_added\': [\'stars\'],\n \'cols_removed\': [\'score\', \'togo\'],\n \'rows_added\': {(\'4C\', \'taco\'): {\'pic\': \'🌮\', \'price\': \'$8.33\', \'stars\': 3.1},\n                (\'5B\', \'pizza\'): {\'pic\': \'🍕\', \'price\': \'$9.99\', \'stars\': 2.4}},\n \'rows_changed\': {(\'1A\', \'beer\'): [(\'pic\', \'🍺\', \'🍻\'),\n                                   (\'price\', \'$6.00\', \'$5.25\')],\n                  (\'2A\', \'cheese\'): [(\'price\', \'$4.10\', \'$3.95\')]},\n \'rows_removed\': {(\'3A\', \'bacon\'): {\'pic\': \'🥓\',\n                                    \'price\': \'$3.33\',\n                                    \'score\': 4.9,\n                                    \'togo\': \'Y\'}}}\n```\n\nSee the docs for detailed usage and examples.\n\n\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n<!-- INSTALLATION -->\n## Installation\n### Prerequisites\n  - [Python](https://www.python.org/) v3.6 or greater\n  - [Poetry](https://python-poetry.org/)\n\nThen simply run:\n```sh\npoetry install csvcomparer\n```\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n<!-- ROADMAP -->\n## Roadmap\n**csvcomparer** is in its infancy, and there are high hopes for this project!\n\nThe ultimate goal is being able to compare any two data sets that can be consumed as a "dataframe", regardless of size, efficiently as possible. This comes with a great deal of challenges, but I\'m confident it will get there. \n\nSee the [open issues](https://github.com/bergsmith/csvcomparer/issues) for a full list of proposed features (and known issues).\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n<!-- CONTRIBUTING -->\n## Contributing\nAny contributions are **greatly appreciated**.\n\nIf you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".\nDon\'t forget to give the project a star! Thanks again!\n\n1. Fork the Project\n2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)\n3. Commit your Changes (`git commit -m \'Add some AmazingFeature\'`)\n4. Push to the Branch (`git push origin feature/AmazingFeature`)\n5. Open a Pull Request\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n<!-- LICENSE -->\n## License\nDistributed under the MIT License. See `LICENSE.txt` for more information.\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n<!-- CONTACT -->\n## Contact\nRyan Bergsmith - [LinkedIn](https://www.linkedin.com/in/bergsmith/) - ryguydev@gmail.com  \nProject Link: [Github](https://github.com/bergsmith/csvcomparer)\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n<!-- ACKNOWLEDGMENTS -->\n## Acknowledgments\n  - [Robin Zaubeerer](https://github.com/Zaubeerer) for being a great [PDM](https://pybit.es/catalogue/the-pdm-program/) coach and providing roadmap inspiration.\n\n<p align="right">(<a href="#top">back to top</a>)</p>',
    'author': 'Ryan Bergsmith',
    'author_email': 'ryguydev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bergsmith/csvcomparer',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
